@@ -25,6 +25,7 @@
 #include <config.h>
 
 #include <osinfo/osinfo.h>
+#include <glib/gi18n-lib.h>
 
 G_DEFINE_ABSTRACT_TYPE (OsinfoEntity, osinfo_entity, G_TYPE_OBJECT);
 
@@ -132,7 +133,7 @@ osinfo_entity_class_init (OsinfoEntityClass *klass)
      */
     pspec = g_param_spec_string ("id",
                                  "ID",
-                                 "Unique identifier",
+                                 _("Unique identifier"),
                                  NULL /* default value */,
                                  G_PARAM_CONSTRUCT_ONLY |
                                  G_PARAM_READWRITE |
@@ -205,11 +206,26 @@ void osinfo_entity_set_param_int64(OsinfoEntity *entity, const gchar *key, gint6
 {
     gchar *str;
 
-    str = g_strdup_printf("%"G_GUINT64_FORMAT, value);
+    str = g_strdup_printf("%"G_GINT64_FORMAT, value);
     osinfo_entity_set_param(entity, key, str);
     g_free(str);
 }
 
+void osinfo_entity_set_param_enum(OsinfoEntity *entity, const gchar *key, gint value, GType enum_type)
+{
+    GEnumClass *enum_class;
+    GEnumValue *enum_value;
+
+    g_return_if_fail(G_TYPE_IS_ENUM (enum_type));
+
+    enum_class = g_type_class_ref(enum_type);
+    enum_value = g_enum_get_value(enum_class, value);
+    g_type_class_unref(enum_class);
+    g_return_if_fail(enum_value != NULL);
+
+    osinfo_entity_set_param(entity, key, enum_value->value_nick);
+}
+
 /**
  * osinfo_entity_add_param:
  * @entity: OsinfoEntity containing the parameters
@@ -348,28 +364,46 @@ gboolean osinfo_entity_get_param_value_boolean_with_default(OsinfoEntity *entity
 gint64 osinfo_entity_get_param_value_int64(OsinfoEntity *entity,
                                            const gchar *key)
 {
-    const gchar *str;
-
-    str = osinfo_entity_get_param_value(entity, key);
-
-    if (str == NULL)
-        return -1;
-
-    return (gint64) g_ascii_strtod(str, NULL);
+    return osinfo_entity_get_param_value_int64_with_default(entity, key, -1);
 }
 
 gint64 osinfo_entity_get_param_value_int64_with_default(OsinfoEntity *entity,
                                                         const gchar *key,
                                                         gint64 default_value)
 {
-    gint64 value;
+    const gchar *str;
 
-    value = osinfo_entity_get_param_value_int64(entity, key);
+    str = osinfo_entity_get_param_value(entity, key);
 
-    if (value < 0)
+    if (str == NULL)
         return default_value;
 
-    return value;
+    return g_ascii_strtoll(str, NULL, 0);
+}
+
+gint osinfo_entity_get_param_value_enum(OsinfoEntity *entity,
+                                        const char *key,
+                                        GType enum_type,
+                                        gint default_value)
+{
+    const gchar *nick;
+    GEnumClass *enum_class;
+    GEnumValue *enum_value;
+
+    g_return_val_if_fail(G_TYPE_IS_ENUM(enum_type), default_value);
+
+    nick = osinfo_entity_get_param_value(entity, key);
+    if (nick == NULL)
+        return default_value;
+
+    enum_class = g_type_class_ref(enum_type);
+    enum_value = g_enum_get_value_by_nick(enum_class, nick);
+    g_type_class_unref(enum_class);
+
+    if (enum_value != NULL)
+        return enum_value->value;
+
+    g_return_val_if_reached(default_value);
 }
 
 /**
