@@ -2,6 +2,7 @@
  * libosinfo:
  *
  * Copyright (C) 2009-2012 Red Hat, Inc.
+ * Copyright (C) 2012 Fabiano Fidêncio
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -24,6 +25,7 @@
 #include <config.h>
 
 #include <osinfo/osinfo.h>
+#include <glib/gi18n-lib.h>
 
 G_DEFINE_TYPE (OsinfoInstallConfigParam, osinfo_install_config_param, OSINFO_TYPE_ENTITY);
 
@@ -39,12 +41,6 @@ G_DEFINE_TYPE (OsinfoInstallConfigParam, osinfo_install_config_param, OSINFO_TYP
  * generate an automated installation script
  */
 
-struct _OsinfoInstallConfigParamPrivate
-{
-    gchar *name;
-    OsinfoInstallConfigParamPolicy policy;
-};
-
 enum {
     PROP_0,
 
@@ -61,27 +57,17 @@ osinfo_install_config_param_set_property(GObject *object,
     OsinfoInstallConfigParam *config_param =
         OSINFO_INSTALL_CONFIG_PARAM (object);
 
-    switch (property_id)
-        {
-        case PROP_NAME:
-            config_param->priv->name = g_value_dup_string(value);
-            break;
-        case PROP_POLICY:
-            {
-            const gchar *policy = g_value_get_string(value);
-            if (g_strcmp0(policy, "required") == 0)
-                config_param->priv->policy =
-                    OSINFO_INSTALL_CONFIG_PARAM_POLICY_REQUIRED;
-            else if (g_strcmp0(policy, "optional") == 0)
-                config_param->priv->policy =
-                    OSINFO_INSTALL_CONFIG_PARAM_POLICY_OPTIONAL;
-            break;
-            }
-        default:
-            /* We don't have any other property... */
-            G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
-            break;
-        }
+    switch (property_id) {
+    case PROP_NAME:
+        osinfo_entity_set_param(OSINFO_ENTITY(config_param),
+                                OSINFO_INSTALL_CONFIG_PARAM_PROP_NAME,
+                                g_value_get_string(value));
+        break;
+    default:
+        /* We don't have any other property... */
+        G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
+        break;
+    }
 }
 
 static void
@@ -93,31 +79,28 @@ osinfo_install_config_param_get_property(GObject *object,
     OsinfoInstallConfigParam *config_param =
         OSINFO_INSTALL_CONFIG_PARAM (object);
 
-    switch (property_id)
-        {
-        case PROP_NAME:
-            g_value_set_string(value, config_param->priv->name);
-            break;
-        case PROP_POLICY:
-            g_value_set_enum(value, config_param->priv->policy);
-            break;
-        default:
-            /* We don't have any other property... */
-            G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
-            break;
-        }
-}
+    switch (property_id) {
+    case PROP_NAME:
+    {
+        const gchar *name;
 
+        name = osinfo_install_config_param_get_name(config_param);
+        g_value_set_string(value, name);
+        break;
+    }
+    case PROP_POLICY:
+    {
+        OsinfoInstallConfigParamPolicy policy;
 
-static void
-osinfo_install_config_param_finalize(GObject *object)
-{
-    OsinfoInstallConfigParam *config_param =
-        OSINFO_INSTALL_CONFIG_PARAM(object);
-    g_free(config_param->priv->name);
-
-    /* Chain up to the parent class */
-    G_OBJECT_CLASS (osinfo_install_config_param_parent_class)->finalize (object);
+        policy = osinfo_install_config_param_get_policy(config_param);
+        g_value_set_enum(value, policy);
+        break;
+    }
+    default:
+        /* We don't have any other property... */
+        G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
+        break;
+    }
 }
 
 /* Init functions */
@@ -137,7 +120,7 @@ osinfo_install_config_param_class_init (OsinfoInstallConfigParamClass *klass)
      **/
     pspec = g_param_spec_string("name",
                                 "Name",
-                                "Parameter name",
+                                _("Parameter name"),
                                 NULL,
                                 G_PARAM_WRITABLE |
                                 G_PARAM_READABLE |
@@ -153,54 +136,37 @@ osinfo_install_config_param_class_init (OsinfoInstallConfigParamClass *klass)
      *
      * The policy of the configuration parameter.
      **/
-    pspec = g_param_spec_string("policy",
-                                "Policy",
-                                "Parameter policy",
-                                NULL,
-                                G_PARAM_WRITABLE |
-                                G_PARAM_READABLE |
-                                G_PARAM_CONSTRUCT_ONLY |
-                                G_PARAM_STATIC_NAME |
-                                G_PARAM_STATIC_NICK |
-                                G_PARAM_STATIC_BLURB);
+    pspec = g_param_spec_enum("policy",
+                              "Policy",
+                              _("Parameter policy"),
+                              OSINFO_TYPE_INSTALL_CONFIG_PARAM_POLICY,
+                              OSINFO_INSTALL_CONFIG_PARAM_POLICY_OPTIONAL,
+                              G_PARAM_READABLE |
+                              G_PARAM_STATIC_NAME |
+                              G_PARAM_STATIC_NICK |
+                              G_PARAM_STATIC_BLURB);
     g_object_class_install_property(g_klass,
                                     PROP_POLICY,
                                     pspec);
-
-
-    g_klass->finalize = osinfo_install_config_param_finalize;
-
-    g_type_class_add_private (klass, sizeof (OsinfoInstallConfigParamPrivate));
 }
 
 static void
 osinfo_install_config_param_init (OsinfoInstallConfigParam *config_param)
 {
-    OsinfoInstallConfigParamPrivate *priv;
-    config_param->priv = priv =
-        OSINFO_INSTALL_CONFIG_PARAM_GET_PRIVATE(config_param);
-
-    config_param->priv->name = NULL;
-    config_param->priv->policy = OSINFO_INSTALL_CONFIG_PARAM_POLICY_NONE;
+   /* G_DEFINE_TYPE() needs an instance init function */
 }
 
-
 /**
  * osinfo_install_config_param_new:
  * @name: the configuration parameter name
- * @policy: the configuration parameter policy
  *
  * Construct a new configuration parameter to a #OsinfoInstallScript.
  *
  * Returns: (transfer full): the new configuration parameter
  */
-OsinfoInstallConfigParam *osinfo_install_config_param_new(const gchar *name,
-                                                          const gchar *policy)
+OsinfoInstallConfigParam *osinfo_install_config_param_new(const gchar *name)
 {
-    return g_object_new(OSINFO_TYPE_INSTALL_CONFIG_PARAM,
-                        "name", name,
-                        "policy", policy,
-                        NULL);
+    return g_object_new(OSINFO_TYPE_INSTALL_CONFIG_PARAM, "name", name, NULL);
 }
 
 /**
@@ -211,7 +177,8 @@ OsinfoInstallConfigParam *osinfo_install_config_param_new(const gchar *name,
  */
 const gchar *osinfo_install_config_param_get_name(const OsinfoInstallConfigParam *config_param)
 {
-    return config_param->priv->name;
+    return osinfo_entity_get_param_value(OSINFO_ENTITY(config_param),
+                                         OSINFO_INSTALL_CONFIG_PARAM_PROP_NAME);
 }
 
 /**
@@ -222,7 +189,10 @@ const gchar *osinfo_install_config_param_get_name(const OsinfoInstallConfigParam
  */
 OsinfoInstallConfigParamPolicy osinfo_install_config_param_get_policy(const OsinfoInstallConfigParam *config_param)
 {
-    return config_param->priv->policy;
+    return osinfo_entity_get_param_value_enum(OSINFO_ENTITY(config_param),
+                                              OSINFO_INSTALL_CONFIG_PARAM_PROP_POLICY,
+                                              OSINFO_TYPE_INSTALL_CONFIG_PARAM_POLICY,
+                                              OSINFO_INSTALL_CONFIG_PARAM_POLICY_OPTIONAL);
 }
 
 /**
@@ -234,11 +204,8 @@ OsinfoInstallConfigParamPolicy osinfo_install_config_param_get_policy(const Osin
  */
 gboolean osinfo_install_config_param_is_required(const OsinfoInstallConfigParam *config_param)
 {
-    if (config_param->priv->policy ==
-            OSINFO_INSTALL_CONFIG_PARAM_POLICY_REQUIRED)
-        return TRUE;
-
-    return FALSE;
+    return (osinfo_install_config_param_get_policy(config_param) ==
+            OSINFO_INSTALL_CONFIG_PARAM_POLICY_REQUIRED);
 }
 
 /**
@@ -250,11 +217,8 @@ gboolean osinfo_install_config_param_is_required(const OsinfoInstallConfigParam
  */
 gboolean osinfo_install_config_param_is_optional(const OsinfoInstallConfigParam *config_param)
 {
-    if (config_param->priv->policy ==
-            OSINFO_INSTALL_CONFIG_PARAM_POLICY_OPTIONAL)
-        return TRUE;
-
-    return FALSE;
+    return (osinfo_install_config_param_get_policy(config_param) ==
+            OSINFO_INSTALL_CONFIG_PARAM_POLICY_OPTIONAL);
 }
 
 /*
