@@ -2,6 +2,7 @@
  * libosinfo: OS installation configuration parameter
  *
  * Copyright (C) 2009-2012 Red Hat, Inc.
+ * Copyright (C) 2012 Fabiano Fidêncio
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -36,10 +37,20 @@
 #define OSINFO_IS_INSTALL_CONFIG_PARAM_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), OSINFO_TYPE_INSTALL_CONFIG_PARAM))
 #define OSINFO_INSTALL_CONFIG_PARAM_GET_CLASS(obj)  (G_TYPE_INSTANCE_GET_CLASS ((obj), OSINFO_TYPE_INSTALL_CONFIG_PARAM, OsinfoInstallConfigParamClass))
 
+#define OSINFO_INSTALL_CONFIG_PARAM_PROP_NAME   "name"
+#define OSINFO_INSTALL_CONFIG_PARAM_PROP_POLICY "policy"
+
 typedef struct _OsinfoInstallConfigParam        OsinfoInstallConfigParam;
 typedef struct _OsinfoInstallConfigParamClass   OsinfoInstallConfigParamClass;
 typedef struct _OsinfoInstallConfigParamPrivate OsinfoInstallConfigParamPrivate;
-
+/**
+ * OsinfoInstallConfigParamPolicy:
+ * @OSINFO_INSTALL_CONFIG_PARAM_POLICY_NONE: no policy defined
+ * @OSINFO_INSTALL_CONFIG_PARAM_POLICY_REQUIRED: config parameter is required
+ * @OSINFO_INSTALL_CONFIG_PARAM_POLICY_OPTIONAL: config parameter may be omitted
+ *
+ * Policy for configuration parameter presence
+ */
 typedef enum {
     OSINFO_INSTALL_CONFIG_PARAM_POLICY_NONE,
     OSINFO_INSTALL_CONFIG_PARAM_POLICY_REQUIRED,
@@ -59,6 +70,7 @@ struct _OsinfoInstallConfigParam
 /* class */
 struct _OsinfoInstallConfigParamClass
 {
+    /*< private >*/
     OsinfoEntityClass parent_class;
 
     /* class members */
@@ -66,7 +78,7 @@ struct _OsinfoInstallConfigParamClass
 
 GType osinfo_install_config_param_get_type(void);
 
-OsinfoInstallConfigParam *osinfo_install_config_param_new(const gchar *name, const gchar *policy);
+OsinfoInstallConfigParam *osinfo_install_config_param_new(const gchar *name);
 
 const gchar *osinfo_install_config_param_get_name(const OsinfoInstallConfigParam *config_param);
 
