@@ -29,6 +29,8 @@
 #include <libxslt/transform.h>
 #include <libxslt/xsltutils.h>
 #include <libxslt/xsltInternals.h>
+#include <glib/gi18n-lib.h>
+#include "osinfo_install_script_private.h"
 
 G_DEFINE_TYPE (OsinfoInstallScript, osinfo_install_script, OSINFO_TYPE_ENTITY);
 
@@ -49,6 +51,7 @@ struct _OsinfoInstallScriptPrivate
     gchar *output_prefix;
     gchar *output_filename;
     GList *config_param_list;
+    OsinfoAvatarFormat *avatar;
 };
 
 enum {
@@ -58,6 +61,8 @@ enum {
     PROP_TEMPLATE_DATA,
     PROP_PROFILE,
     PROP_PRODUCT_KEY_FORMAT,
+    PROP_PATH_FORMAT,
+    PROP_AVATAR_FORMAT,
 };
 
 typedef struct _OsinfoInstallScriptGenerateData OsinfoInstallScriptGenerateData;
@@ -66,10 +71,10 @@ typedef struct _OsinfoInstallScriptGenerateSyncData OsinfoInstallScriptGenerateS
 
 
 static void
-osinfo_os_set_property(GObject    *object,
-                       guint       property_id,
-                       const GValue     *value,
-                       GParamSpec *pspec)
+osinfo_install_script_set_property(GObject    *object,
+                                   guint       property_id,
+                                   const GValue     *value,
+                                   GParamSpec *pspec)
 {
     OsinfoInstallScript *script = OSINFO_INSTALL_SCRIPT(object);
     const gchar *data;
@@ -107,10 +112,10 @@ osinfo_os_set_property(GObject    *object,
 }
 
 static void
-osinfo_os_get_property(GObject    *object,
-                       guint       property_id,
-                       GValue     *value,
-                       GParamSpec *pspec)
+osinfo_install_script_get_property(GObject    *object,
+                                   guint       property_id,
+                                   GValue     *value,
+                                   GParamSpec *pspec)
 {
     OsinfoInstallScript *script = OSINFO_INSTALL_SCRIPT(object);
 
@@ -135,6 +140,16 @@ osinfo_os_get_property(GObject    *object,
                            osinfo_install_script_get_product_key_format(script));
         break;
 
+    case PROP_PATH_FORMAT:
+        g_value_set_enum(value,
+                         osinfo_install_script_get_path_format(script));
+        break;
+
+    case PROP_AVATAR_FORMAT:
+        g_value_set_object(value,
+                           osinfo_install_script_get_avatar_format(script));
+        break;
+
     default:
         /* We don't have any other property... */
         G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
@@ -150,6 +165,8 @@ osinfo_install_script_finalize (GObject *object)
     g_free(script->priv->output_prefix);
     g_free(script->priv->output_filename);
     g_list_free_full(script->priv->config_param_list, g_object_unref);
+    if (script->priv->avatar != NULL)
+        g_object_unref(script->priv->avatar);
 
     /* Chain up to the parent class */
     G_OBJECT_CLASS (osinfo_install_script_parent_class)->finalize (object);
@@ -162,62 +179,75 @@ osinfo_install_script_class_init (OsinfoInstallScriptClass *klass)
     GObjectClass *g_klass = G_OBJECT_CLASS (klass);
     GParamSpec *pspec;
 
-    g_klass->get_property = osinfo_os_get_property;
-    g_klass->set_property = osinfo_os_set_property;
+    g_klass->get_property = osinfo_install_script_get_property;
+    g_klass->set_property = osinfo_install_script_set_property;
     g_klass->finalize = osinfo_install_script_finalize;
 
     pspec = g_param_spec_string("template-uri",
                                 "TemplateURI",
-                                "URI for install script template",
+                                _("URI for install script template"),
                                 NULL /* default value */,
                                 G_PARAM_READABLE |
                                 G_PARAM_WRITABLE |
                                 G_PARAM_CONSTRUCT_ONLY |
-                                G_PARAM_STATIC_NAME |
-                                G_PARAM_STATIC_NICK |
-                                G_PARAM_STATIC_BLURB);
+                                G_PARAM_STATIC_STRINGS);
     g_object_class_install_property(g_klass,
                                     PROP_TEMPLATE_URI,
                                     pspec);
 
     pspec = g_param_spec_string("template-data",
                                 "TemplateData",
-                                "Data for install script template",
+                                _("Data for install script template"),
                                 NULL /* default value */,
                                 G_PARAM_READABLE |
                                 G_PARAM_WRITABLE |
                                 G_PARAM_CONSTRUCT_ONLY |
-                                G_PARAM_STATIC_NAME |
-                                G_PARAM_STATIC_NICK |
-                                G_PARAM_STATIC_BLURB);
+                                G_PARAM_STATIC_STRINGS);
     g_object_class_install_property(g_klass,
                                     PROP_TEMPLATE_DATA,
                                     pspec);
 
     pspec = g_param_spec_string("profile",
                                 "Profile",
-                                "Install script profile name",
+                                _("Install script profile name"),
                                 NULL /* default value */,
                                 G_PARAM_READABLE |
                                 G_PARAM_WRITABLE |
                                 G_PARAM_CONSTRUCT_ONLY |
-                                G_PARAM_STATIC_NAME |
-                                G_PARAM_STATIC_NICK |
-                                G_PARAM_STATIC_BLURB);
+                                G_PARAM_STATIC_STRINGS);
     g_object_class_install_property(g_klass,
                                     PROP_PROFILE,
                                     pspec);
 
     pspec = g_param_spec_string("product-key-format",
                                 "Product Key Format",
-                                "Product key format mask",
+                                _("Product key format mask"),
                                 NULL /* default value */,
                                 G_PARAM_READABLE |
-                                G_PARAM_STATIC_NAME |
-                                G_PARAM_STATIC_NICK |
-                                G_PARAM_STATIC_BLURB);
+                                G_PARAM_STATIC_STRINGS);
     g_object_class_install_property(g_klass,
-                                    PROP_PROFILE,
+                                    PROP_PRODUCT_KEY_FORMAT,
+                                    pspec);
+
+    pspec = g_param_spec_enum("path-format",
+                              "Path Format",
+                              _("Expected path format"),
+                              OSINFO_TYPE_PATH_FORMAT,
+                              OSINFO_PATH_FORMAT_UNIX /* default value */,
+                              G_PARAM_READABLE |
+                              G_PARAM_STATIC_STRINGS);
+    g_object_class_install_property(g_klass,
+                                    PROP_PATH_FORMAT,
+                                    pspec);
+
+    pspec = g_param_spec_object("avatar-format",
+                                "Avatar Format",
+                                _("Expected avatar format"),
+                                OSINFO_TYPE_AVATAR_FORMAT,
+                                G_PARAM_READABLE |
+                                G_PARAM_STATIC_STRINGS);
+    g_object_class_install_property(g_klass,
+                                    PROP_AVATAR_FORMAT,
                                     pspec);
 
     g_type_class_add_private (klass, sizeof (OsinfoInstallScriptPrivate));
@@ -259,6 +289,15 @@ gboolean osinfo_install_script_has_config_param_name(const OsinfoInstallScript *
     return FALSE;
 }
 
+/**
+ * osinfo_install_script_get_config_param_list:
+ *
+ * Get the list of valid config parameters for @script.
+ *
+ * Returns: (transfer container) (element-type OsinfoInstallScript): the
+ * list of valid #OsinfoInstallConfigParam parameters. Free with
+ * g_list_free() when done. The elements are owned by libosinfo.
+ */
 GList *osinfo_install_script_get_config_param_list(const OsinfoInstallScript *script)
 {
     return g_list_copy(script->priv->config_param_list);
@@ -266,6 +305,8 @@ GList *osinfo_install_script_get_config_param_list(const OsinfoInstallScript *sc
 
 /**
  * osinfo_install_script_get_config_param:
+ * @script: the install script
+ * @name: name of the parameter
  *
  * Get a config param from the config param's list
  *
@@ -307,6 +348,9 @@ OsinfoInstallScript *osinfo_install_script_new(const gchar *id)
 
 /**
  * osinfo_install_script_new_data:
+ * @id: a unique identifier
+ * @profile: the profile of script
+ * @templateData: style sheet data
  *
  * Construct a new install script from stylesheet data
  *
@@ -326,6 +370,9 @@ OsinfoInstallScript *osinfo_install_script_new_data(const gchar *id,
 
 /**
  * osinfo_install_script_new_uri:
+ * @id: a unique identifier
+ * @profile: the profile of script
+ * @templateUri: style sheet URI
  *
  * Construct a new install script from a stylesheet URI
  *
@@ -361,6 +408,30 @@ const gchar *osinfo_install_script_get_profile(OsinfoInstallScript *script)
                                          OSINFO_INSTALL_SCRIPT_PROP_PROFILE);
 }
 
+/**
+ * osinfo_install_script_get_product_key_format:
+ * @script: the install script
+ *
+ * If this function returns a non-NULL string, it means that the @script
+ * requires you to specify product registration key through #OsinfoInstallConfig
+ * instance passed to script generation methods.
+ *
+ * The returned string specifies the expected format of the product key like this:
+ *
+ * @ - any character
+ * % - alphabet
+ * # - numeric character
+ * $ - alphanumeric character
+ *
+ * All other characters represent themselves.
+ *
+ * For example in case of installer for Microsoft Windows XP, you'll get
+ * "$$$$$-$$$$$-$$$$$-$$$$$-$$$$$". That means a product key consists of 24
+ * alphanumeric characters and 4 '-' characters at (0-based) indices 5, 11, 17
+ * and 23.
+ *
+ * Returns: (transfer none): Product key format mask, or NULL.
+ */
 const gchar *osinfo_install_script_get_product_key_format(OsinfoInstallScript *script)
 {
     return osinfo_entity_get_param_value(OSINFO_ENTITY(script),
@@ -391,6 +462,7 @@ const gchar *osinfo_install_script_get_output_prefix(OsinfoInstallScript *script
 
 /**
  * osinfo_install_script_get_expected_filename:
+ * @script: the install script
  *
  * Some operating systems (as Windows) expect that script filename has
  * particular name to work.
@@ -405,6 +477,7 @@ const gchar *osinfo_install_script_get_expected_filename(OsinfoInstallScript *sc
 
 /**
  * osinfo_install_script_get_output_filename:
+ * @script: the install script
  *
  * Some operating systems are able to use any script filename, allowing the
  * application to set the filename as desired. libosinfo provides this
@@ -421,6 +494,39 @@ const gchar *osinfo_install_script_get_output_filename(OsinfoInstallScript *scri
     return script->priv->output_filename;
 }
 
+void
+osinfo_install_script_set_avatar_format(OsinfoInstallScript *script,
+                                        OsinfoAvatarFormat *avatar)
+{
+    g_return_if_fail(OSINFO_IS_INSTALL_SCRIPT(script));
+    g_return_if_fail(OSINFO_IS_AVATAR_FORMAT(avatar));
+
+    if (script->priv->avatar != NULL)
+        g_object_unref(script->priv->avatar);
+    script->priv->avatar = g_object_ref(avatar);
+}
+
+/**
+ * osinfo_install_script_get_avatar_format
+ * @script: the install script
+ *
+ * Some install scripts have restrictions on the format of the user avatar. Use
+ * this method to retrieve those restrictions in the form of an
+ * #OsinfoAvatarFormat instance.
+ *
+ * Returns: (transfer none): The avatar format, or NULL if there is no restrictions on the
+ *                           format of avatar
+ */
+OsinfoAvatarFormat *osinfo_install_script_get_avatar_format(OsinfoInstallScript *script)
+{
+    g_return_val_if_fail(OSINFO_IS_INSTALL_SCRIPT(script), NULL);
+
+    if (script->priv->avatar == NULL)
+        return NULL;
+
+    return script->priv->avatar;
+}
+
 struct _OsinfoInstallScriptGenerateData {
     GSimpleAsyncResult *res;
     OsinfoOs *os;
@@ -469,7 +575,7 @@ static xsltStylesheetPtr osinfo_install_script_load_template(const gchar *uri,
     pctxt = xmlNewParserCtxt();
     if (!pctxt || !pctxt->sax) {
         g_set_error(error, 0, 0, "%s",
-                    "Unable to create XML parser context");
+                    _("Unable to create XML parser context"));
         goto cleanup;
     }
 
@@ -477,13 +583,13 @@ static xsltStylesheetPtr osinfo_install_script_load_template(const gchar *uri,
                                XML_PARSE_NOENT | XML_PARSE_NONET |
                                XML_PARSE_NOWARNING))) {
         g_set_error(error, 0, 0, "%s",
-                    "Unable to read XSL template");
+                    _("Unable to read XSL template"));
         goto cleanup;
     }
 
     if (!(xslt = xsltParseStylesheetDoc(doc))) {
         g_set_error(error, 0, 0, "%s",
-                    "Unable to parse XSL template");
+                    _("Unable to parse XSL template"));
         goto cleanup;
     }
 
@@ -504,7 +610,7 @@ static xmlNodePtr osinfo_install_script_generate_entity_config(OsinfoInstallConf
 
     if (!(node = xmlNewDocNode(NULL, NULL, (xmlChar*)name, NULL))) {
         xmlErrorPtr err = xmlGetLastError();
-        g_set_error(error, 0, 0, "Unable to create XML node '%s': '%s'",
+        g_set_error(error, 0, 0, _("Unable to create XML node '%s': '%s'"),
                     name, err ? err->message : "");
         goto error;
     }
@@ -512,13 +618,13 @@ static xmlNodePtr osinfo_install_script_generate_entity_config(OsinfoInstallConf
     if (!(data = xmlNewDocNode(NULL, NULL, (const xmlChar*)"id",
                                (const xmlChar*)osinfo_entity_get_id(entity)))) {
         xmlErrorPtr err = xmlGetLastError();
-        g_set_error(error, 0, 0, "Unable to create XML node 'id': '%s'",
+        g_set_error(error, 0, 0, _("Unable to create XML node 'id': '%s'"),
                     err ? err->message : "");
         goto error;
     }
     if (!(xmlAddChild(node, data))) {
         xmlErrorPtr err = xmlGetLastError();
-        g_set_error(error, 0, 0, "Unable to add XML child '%s'", err ? err->message : "");
+        g_set_error(error, 0, 0, _("Unable to add XML child '%s'"), err ? err->message : "");
         goto error;
     }
     data = NULL;
@@ -532,13 +638,13 @@ static xmlNodePtr osinfo_install_script_generate_entity_config(OsinfoInstallConf
             if (!(data = xmlNewDocNode(NULL, NULL, (const xmlChar*)tmp1->data,
                                        (const xmlChar*)tmp2->data))) {
                 xmlErrorPtr err = xmlGetLastError();
-                g_set_error(error, 0, 0, "Unable to create XML node '%s': '%s'",
+                g_set_error(error, 0, 0, _("Unable to create XML node '%s': '%s'"),
                             (const gchar *)tmp1->data, err ? err->message : "");
                 goto error;
             }
             if (!(xmlAddChild(node, data))) {
                 xmlErrorPtr err = xmlGetLastError();
-                g_set_error(error, 0, 0, "Unable to add XML child '%s'", err ? err->message : "");
+                g_set_error(error, 0, 0, _("Unable to add XML child '%s'"), err ? err->message : "");
                 goto error;
             }
             data = NULL;
@@ -582,7 +688,7 @@ static xmlDocPtr osinfo_install_script_generate_config_xml(OsinfoInstallScript *
         goto error;
     if (!(xmlAddChild(root, node))) {
         xmlErrorPtr err = xmlGetLastError();
-        g_set_error(error, 0, 0, "Unable to set XML root '%s'", err ? err->message : "");
+        g_set_error(error, 0, 0, _("Unable to set XML root '%s'"), err ? err->message : "");
         goto error;
     }
 
@@ -593,7 +699,7 @@ static xmlDocPtr osinfo_install_script_generate_config_xml(OsinfoInstallScript *
         goto error;
     if (!(xmlAddChild(root, node))) {
         xmlErrorPtr err = xmlGetLastError();
-        g_set_error(error, 0, 0, "Unable to set XML root '%s'", err ? err->message : "");
+        g_set_error(error, 0, 0, _("Unable to set XML root '%s'"), err ? err->message : "");
         goto error;
     }
 
@@ -604,7 +710,7 @@ static xmlDocPtr osinfo_install_script_generate_config_xml(OsinfoInstallScript *
         goto error;
     if (!(xmlAddChild(root, node))) {
         xmlErrorPtr err = xmlGetLastError();
-        g_set_error(error, 0, 0, "Unable to set XML root '%s'", err ? err->message : "");
+        g_set_error(error, 0, 0, _("Unable to set XML root '%s'"), err ? err->message : "");
         goto error;
     }
 
@@ -626,17 +732,17 @@ static gchar *osinfo_install_script_apply_xslt(xsltStylesheetPtr ss,
     int len;
 
     if (!(ctxt = xsltNewTransformContext(ss, doc))) {
-        g_set_error(error, 0, 0, "%s", "Unable to create XSL transform context");
+        g_set_error(error, 0, 0, "%s", _("Unable to create XSL transform context"));
         goto cleanup;
     }
 
     if (!(docOut = xsltApplyStylesheetUser(ss, doc, NULL, NULL, NULL, ctxt))) {
-        g_set_error(error, 0, 0, "%s", "Unable to apply XSL transform context");
+        g_set_error(error, 0, 0, "%s", _("Unable to apply XSL transform context"));
         goto cleanup;
     }
 
     if (xsltSaveResultToString((xmlChar **)&ret, &len, docOut, ss) < 0) {
-        g_set_error(error, 0, 0, "%s", "Unable to convert XSL output to string");
+        g_set_error(error, 0, 0, "%s", _("Unable to convert XSL output to string"));
         goto cleanup;
     }
 
@@ -692,7 +798,7 @@ static void osinfo_install_script_template_loaded(GObject *src,
                                      &length,
                                      NULL,
                                      &error)) {
-        g_prefix_error(&error, "Failed to load script template %s: ", uri);
+        g_prefix_error(&error, _("Failed to load script template %s: "), uri);
         g_simple_async_result_take_error(data->res, error);
         goto cleanup;
     }
@@ -705,7 +811,7 @@ static void osinfo_install_script_template_loaded(GObject *src,
                                               &output,
                                               data->config,
                                               &error)) {
-        g_prefix_error(&error, "Failed to apply script template %s: ", uri);
+        g_prefix_error(&error, _("Failed to apply script template %s: "), uri);
         g_simple_async_result_take_error(data->res, error);
         goto cleanup;
     }
@@ -749,7 +855,7 @@ void osinfo_install_script_generate_async(OsinfoInstallScript *script,
                                                   &output,
                                                   data->config,
                                                   &error)) {
-            g_prefix_error(&error, "%s", "Failed to apply script template: ");
+            g_prefix_error(&error, "%s", _("Failed to apply script template: "));
             g_simple_async_result_take_error(data->res, error);
             g_simple_async_result_complete(data->res);
             osinfo_install_script_generate_data_free(data);
@@ -972,6 +1078,8 @@ void osinfo_install_script_generate_output_async(OsinfoInstallScript *script,
  * @config:     the install script config
  * @output_dir: the directory where file containing the output script
  *              will be written
+ * @cancellable: (allow-none): a #GCancellable, or %NULL
+ * @error: The location where to store any error, or %NULL
  *
  * Creates a install script written in a file
  *
@@ -1009,6 +1117,40 @@ GFile *osinfo_install_script_generate_output(OsinfoInstallScript *script,
     return data.file;
 }
 
+OsinfoPathFormat osinfo_install_script_get_path_format(OsinfoInstallScript *script)
+{
+    return osinfo_entity_get_param_value_enum
+        (OSINFO_ENTITY(script),
+         OSINFO_INSTALL_SCRIPT_PROP_PATH_FORMAT,
+         OSINFO_TYPE_PATH_FORMAT,
+         OSINFO_PATH_FORMAT_UNIX);
+}
+
+/**
+ * osinfo_install_script_get_can_pre_install_drivers:
+ * @script: the install script
+ *
+ * Whether install script can install drivers at the very beginning of
+ * installation. This is needed for devices for which the OS in question does
+ * not have out of the box support for and devices are required/prefered to be
+ * available during actual installation.
+ *
+ * Returns: TRUE if install script supports pre-installable drivers, FASLSE otherwise.
+ */
+gboolean osinfo_install_script_get_can_pre_install_drivers(OsinfoInstallScript *script)
+{
+    return osinfo_entity_get_param_value_boolean
+        (OSINFO_ENTITY(script),
+         OSINFO_INSTALL_SCRIPT_PROP_CAN_PRE_INSTALL_DRIVERS);
+}
+
+gboolean osinfo_install_script_get_can_post_install_drivers(OsinfoInstallScript *script)
+{
+    return osinfo_entity_get_param_value_boolean
+        (OSINFO_ENTITY(script),
+         OSINFO_INSTALL_SCRIPT_PROP_CAN_POST_INSTALL_DRIVERS);
+}
+
 /*
  * Local variables:
  *  indent-tabs-mode: nil
