@@ -24,6 +24,7 @@
 #include <glib-object.h>
 #include <gio/gio.h>
 #include <osinfo/osinfo_install_config_param.h>
+#include <osinfo/osinfo_avatar_format.h>
 
 #ifndef __OSINFO_INSTALL_SCRIPT_H__
 #define __OSINFO_INSTALL_SCRIPT_H__
@@ -51,8 +52,9 @@ typedef struct _OsinfoInstallScriptPrivate OsinfoInstallScriptPrivate;
 #define OSINFO_INSTALL_SCRIPT_PROP_PROFILE            "profile"
 #define OSINFO_INSTALL_SCRIPT_PROP_PRODUCT_KEY_FORMAT "product-key-format"
 #define OSINFO_INSTALL_SCRIPT_PROP_EXPECTED_FILENAME  "expected-filename"
-#define OSINFO_INSTALL_SCRIPT_PROP_CONFIG_REQUIRED    "required"
-#define OSINFO_INSTALL_SCRIPT_PROP_CONFIG_OPTIONAL    "optional"
+#define OSINFO_INSTALL_SCRIPT_PROP_PATH_FORMAT        "path-format"
+#define OSINFO_INSTALL_SCRIPT_PROP_CAN_PRE_INSTALL_DRIVERS "can-pre-install-drivers"
+#define OSINFO_INSTALL_SCRIPT_PROP_CAN_POST_INSTALL_DRIVERS "can-post-install-drivers"
 
 /* object */
 struct _OsinfoInstallScript
@@ -68,11 +70,22 @@ struct _OsinfoInstallScript
 /* class */
 struct _OsinfoInstallScriptClass
 {
+    /*< private >*/
     OsinfoEntityClass parent_class;
 
     /* class members */
 };
 
+/**
+ * OsinfoPathFormat:
+ * @OSINFO_PATH_FORMAT_UNIX: Unix/Linux path format, e.g /home/foo/bar.txt
+ * @OSINFO_PATH_FORMAT_DOS: DOS/Windows path format, e.g \My Documents\bar.txt
+ */
+typedef enum {
+    OSINFO_PATH_FORMAT_UNIX,
+    OSINFO_PATH_FORMAT_DOS
+} OsinfoPathFormat;
+
 GType osinfo_install_script_get_type(void);
 
 OsinfoInstallScript *osinfo_install_script_new(const gchar *id);
@@ -97,6 +110,8 @@ const gchar *osinfo_install_script_get_output_filename(OsinfoInstallScript *scri
 
 const gchar *osinfo_install_script_get_expected_filename(OsinfoInstallScript *script);
 
+OsinfoAvatarFormat *osinfo_install_script_get_avatar_format(OsinfoInstallScript *script);
+
 void osinfo_install_script_generate_async(OsinfoInstallScript *script,
                                           OsinfoOs *os,
                                           OsinfoInstallConfig *config,
@@ -142,6 +157,10 @@ OsinfoInstallConfigParam *osinfo_install_script_get_config_param(const OsinfoIns
 void osinfo_install_script_add_config_param(OsinfoInstallScript *script, OsinfoInstallConfigParam *param);
 
 GList *osinfo_install_script_get_config_param_list(const OsinfoInstallScript *script);
+OsinfoPathFormat osinfo_install_script_get_path_format(OsinfoInstallScript *script);
+
+gboolean osinfo_install_script_get_can_pre_install_drivers(OsinfoInstallScript *script);
+gboolean osinfo_install_script_get_can_post_install_drivers(OsinfoInstallScript *script);
 
 #endif /* __OSINFO_INSTALL_SCRIPT_H__ */
 /*
