@@ -23,6 +23,7 @@
  */
 
 #include <config.h>
+#include <glib/gi18n-lib.h>
 
 #include <osinfo/osinfo.h>
 
@@ -33,6 +34,8 @@
 #include <libxml/tree.h>
 #include <libxml/xpath.h>
 #include <libxml/xmlreader.h>
+#include "osinfo_install_script_private.h"
+#include "osinfo_device_driver_private.h"
 
 G_DEFINE_TYPE (OsinfoLoader, osinfo_loader, G_TYPE_OBJECT);
 
@@ -70,6 +73,9 @@ osinfo_loader_class_init (OsinfoLoaderClass *klass)
 {
     GObjectClass *g_klass = G_OBJECT_CLASS (klass);
 
+    bindtextdomain(GETTEXT_PACKAGE, LOCALEDIR);
+    bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
+
     g_klass->finalize = osinfo_loader_finalize;
 
     g_type_class_add_private (klass, sizeof (OsinfoLoaderPrivate));
@@ -128,6 +134,8 @@ osinfo_loader_nodeset(const char *xpath,
     if (obj == NULL)
         return(0);
     if (obj->type != XPATH_NODESET) {
+        g_set_error(err, g_quark_from_static_string("libosinfo"), 0,
+                    _("Expected a nodeset in XPath query %s"), xpath);
         xmlXPathFreeObject(obj);
         return (-1);
     }
@@ -219,14 +227,35 @@ static void osinfo_loader_entity(OsinfoLoader *loader,
                                  GError **err)
 {
     int i = 0;
+    const gchar * const *langs = g_get_language_names ();
 
     /* Standard well-known keys first, allow single value only */
-    for (i = 0 ; keys[i] != NULL ; i++) {
-        gchar *xpath = g_strdup_printf("string(./%s)", keys[i]);
-        gchar *value = osinfo_loader_string(xpath, ctxt, err);
-        g_free(xpath);
-        if (error_is_set(err))
-            return;
+    for (i = 0 ; keys[i] != NULL; i++) {
+        gchar *value = NULL;
+        gchar *xpath;
+        int j;
+
+        /* We are guaranteed to have at least the default "C" locale and we
+         * want to ignore that, hence the NULL check on index 'j + 1'.
+         */
+        for (j = 0; langs[j + 1] != NULL; j++) {
+            xpath = g_strdup_printf("string(./%s[lang('%s')])", keys[i], langs[j]);
+            value = osinfo_loader_string(xpath, ctxt, err);
+            g_free(xpath);
+            if (error_is_set(err))
+                return;
+
+            if (value != NULL)
+                break;
+        }
+
+        if (value == NULL) {
+            xpath = g_strdup_printf("string(./%s)", keys[i]);
+            value = osinfo_loader_string(xpath, ctxt, err);
+            g_free(xpath);
+            if (error_is_set(err))
+                return;
+        }
 
         if (value) {
             osinfo_entity_set_param(entity, keys[i], value);
@@ -245,7 +274,7 @@ static void osinfo_loader_entity(OsinfoLoader *loader,
 
         if (!param->children ||
             param->children->type != XML_TEXT_NODE) {
-            OSINFO_ERROR(err, "Expected a text node attribute value");
+            OSINFO_ERROR(err, _("Expected a text node attribute value"));
             goto cleanup;
         }
 
@@ -324,12 +353,12 @@ static void osinfo_loader_device(OsinfoLoader *loader,
         NULL,
     };
     if (!id) {
-        OSINFO_ERROR(err, "Missing device id property");
+        OSINFO_ERROR(err, _("Missing device id property"));
         return;
     }
 
     OsinfoDevice *device = osinfo_loader_get_device(loader, id);
-    g_free(id);
+    xmlFree(id);
 
     osinfo_loader_entity(loader, OSINFO_ENTITY(device), keys, ctxt, root, err);
 }
@@ -354,11 +383,11 @@ static void osinfo_loader_device_link(OsinfoLoader *loader,
         };
         gchar *id = (gchar *)xmlGetProp(related[i], BAD_CAST "id");
         if (!id) {
-            OSINFO_ERROR(err, "Missing device link id property");
+            OSINFO_ERROR(err, _("Missing device link id property"));
             goto cleanup;
         }
         OsinfoDevice *dev = osinfo_loader_get_device(loader, id);
-        g_free(id);
+        xmlFree(id);
 
         OsinfoDeviceLink *devlink = NULL;
         if (OSINFO_IS_PLATFORM(entity)) {
@@ -398,7 +427,7 @@ static void osinfo_loader_product_relshp(OsinfoLoader *loader,
     for (i = 0 ; i < nrelated ; i++) {
         gchar *id = (gchar *)xmlGetProp(related[i], BAD_CAST "id");
         if (!id) {
-            OSINFO_ERROR(err, "Missing product upgrades id property");
+            OSINFO_ERROR(err, _("Missing product upgrades id property"));
             goto cleanup;
         }
         OsinfoProduct *relproduct;
@@ -406,7 +435,7 @@ static void osinfo_loader_product_relshp(OsinfoLoader *loader,
             relproduct = OSINFO_PRODUCT(osinfo_loader_get_platform(loader, id));
         else
             relproduct = OSINFO_PRODUCT(osinfo_loader_get_os(loader, id));
-        g_free(id);
+        xmlFree(id);
 
         osinfo_product_add_related(product, relshp, relproduct);
     }
@@ -473,12 +502,12 @@ static void osinfo_loader_platform(OsinfoLoader *loader,
         NULL,
     };
     if (!id) {
-        OSINFO_ERROR(err, "Missing platform id property");
+        OSINFO_ERROR(err, _("Missing platform id property"));
         return;
     }
 
     OsinfoPlatform *platform = osinfo_loader_get_platform(loader, id);
-    g_free(id);
+    xmlFree(id);
 
     osinfo_loader_entity(loader, OSINFO_ENTITY(platform), keys, ctxt, root, err);
     if (error_is_set(err))
@@ -504,14 +533,14 @@ static void osinfo_loader_deployment(OsinfoLoader *loader,
         NULL
     };
     if (!id) {
-        OSINFO_ERROR(err, "Missing deployment id property");
+        OSINFO_ERROR(err, _("Missing deployment id property"));
         return;
     }
 
     gchar *osid = osinfo_loader_string("string(./os/@id)", ctxt, err);
     if (!osid && 0) {
-        OSINFO_ERROR(err, "Missing deployment os id property");
-        g_free(id);
+        OSINFO_ERROR(err, _("Missing deployment os id property"));
+        xmlFree(id);
         return;
     }
     OsinfoOs *os = osinfo_loader_get_os(loader, osid);
@@ -519,34 +548,38 @@ static void osinfo_loader_deployment(OsinfoLoader *loader,
 
     gchar *platformid = osinfo_loader_string("string(./platform/@id)", ctxt, err);
     if (!platformid) {
-        OSINFO_ERROR(err, "Missing deployment platform id property");
-        g_free(id);
+        OSINFO_ERROR(err, _("Missing deployment platform id property"));
+        xmlFree(id);
         return;
     }
     OsinfoPlatform *platform = osinfo_loader_get_platform(loader, platformid);
     g_free(platformid);
 
     OsinfoDeployment *deployment = osinfo_deployment_new(id, os, platform);
-    g_free(id);
+    xmlFree(id);
 
     osinfo_loader_entity(loader, OSINFO_ENTITY(deployment), keys, ctxt, root, err);
-    if (error_is_set(err))
+    if (error_is_set(err)) {
+        g_object_unref(G_OBJECT(deployment));
         return;
+    }
 
     osinfo_loader_device_link(loader, OSINFO_ENTITY(deployment),
                               "./devices/device", ctxt, root, err);
-    if (error_is_set(err))
+    if (error_is_set(err)) {
+        g_object_unref(G_OBJECT(deployment));
         return;
+    }
 
     osinfo_db_add_deployment(loader->priv->db, deployment);
 }
 
-static void osinfo_loader_install_config_param(OsinfoLoader *loader,
-                                               OsinfoEntity *entity,
-                                               const gchar *xpath,
-                                               xmlXPathContextPtr ctxt,
-                                               xmlNodePtr root,
-                                               GError **err)
+static void osinfo_loader_install_config_params(OsinfoLoader *loader,
+                                                OsinfoEntity *entity,
+                                                const gchar *xpath,
+                                                xmlXPathContextPtr ctxt,
+                                                xmlNodePtr root,
+                                                GError **err)
 {
     xmlNodePtr *nodes = NULL;
     int nnodes = osinfo_loader_nodeset(xpath, ctxt, &nodes, err);
@@ -555,21 +588,47 @@ static void osinfo_loader_install_config_param(OsinfoLoader *loader,
         return;
 
     for (i = 0 ; i < nnodes ; i++) {
-        gchar *name = (gchar *)xmlGetProp(nodes[i], BAD_CAST "name");
-        gchar *policy = (gchar *)xmlGetProp(nodes[i], BAD_CAST "policy");
-        OsinfoInstallConfigParam *param =
-            osinfo_install_config_param_new(name, policy);
+        gchar *name = (gchar *)xmlGetProp(nodes[i], BAD_CAST OSINFO_INSTALL_CONFIG_PARAM_PROP_NAME);
+        gchar *policy = (gchar *)xmlGetProp(nodes[i], BAD_CAST OSINFO_INSTALL_CONFIG_PARAM_PROP_POLICY);
+        OsinfoInstallConfigParam *param = osinfo_install_config_param_new(name);
+        osinfo_entity_set_param(OSINFO_ENTITY(param),
+                                OSINFO_INSTALL_CONFIG_PARAM_PROP_POLICY,
+                                policy);
         osinfo_install_script_add_config_param(OSINFO_INSTALL_SCRIPT(entity),
                                                param);
 
-        g_free(name);
-        g_free(policy);
+        xmlFree(name);
+        xmlFree(policy);
     };
 
     g_free(nodes);
 }
 
+static OsinfoAvatarFormat *osinfo_loader_avatar_format(OsinfoLoader *loader,
+                                                       xmlXPathContextPtr ctxt,
+                                                       xmlNodePtr root,
+                                                       GError **err)
+{
+    OsinfoAvatarFormat *avatar_format;
+    const gchar *const keys[] = {
+        OSINFO_AVATAR_FORMAT_PROP_MIME_TYPE,
+        OSINFO_AVATAR_FORMAT_PROP_WIDTH,
+        OSINFO_AVATAR_FORMAT_PROP_HEIGHT,
+        OSINFO_AVATAR_FORMAT_PROP_ALPHA,
+        NULL
+    };
 
+    avatar_format = osinfo_avatar_format_new();
+
+    osinfo_loader_entity(loader, OSINFO_ENTITY(avatar_format), keys, ctxt, root, err);
+    if (error_is_set(err)) {
+        g_object_unref (avatar_format);
+
+        return NULL;
+    }
+
+    return avatar_format;
+}
 
 static void osinfo_loader_install_script(OsinfoLoader *loader,
                                          xmlXPathContextPtr ctxt,
@@ -580,18 +639,24 @@ static void osinfo_loader_install_script(OsinfoLoader *loader,
     const gchar *const keys[] = {
         OSINFO_INSTALL_SCRIPT_PROP_PROFILE,
         OSINFO_INSTALL_SCRIPT_PROP_PRODUCT_KEY_FORMAT,
+        OSINFO_INSTALL_SCRIPT_PROP_PATH_FORMAT,
+        OSINFO_INSTALL_SCRIPT_PROP_EXPECTED_FILENAME,
+        OSINFO_INSTALL_SCRIPT_PROP_CAN_PRE_INSTALL_DRIVERS,
+        OSINFO_INSTALL_SCRIPT_PROP_CAN_POST_INSTALL_DRIVERS,
         NULL
     };
     gchar *value = NULL;
+    xmlNodePtr *nodes = NULL;
+    int nnodes;
 
     if (!id) {
-        OSINFO_ERROR(err, "Missing install script id property");
+        OSINFO_ERROR(err, _("Missing install script id property"));
         return;
     }
 
     OsinfoInstallScript *installScript = osinfo_loader_get_install_script(loader,
                                                                           id);
-    g_free(id);
+    xmlFree(id);
 
     osinfo_loader_entity(loader, OSINFO_ENTITY(installScript), keys, ctxt, root, err);
     if (error_is_set(err))
@@ -615,27 +680,37 @@ static void osinfo_loader_install_script(OsinfoLoader *loader,
                                 value);
     g_free(value);
 
-    value = osinfo_loader_string("string(./template/@filename)", ctxt, err);
+    osinfo_loader_install_config_params(loader,
+                                        OSINFO_ENTITY(installScript),
+                                        "./config/*",
+                                        ctxt,
+                                        root,
+                                        err);
+
+    nnodes = osinfo_loader_nodeset("./avatar-format", ctxt, &nodes, err);
     if (error_is_set(err))
         goto error;
-    if (value)
-        osinfo_entity_set_param(OSINFO_ENTITY(installScript),
-                                OSINFO_INSTALL_SCRIPT_PROP_EXPECTED_FILENAME,
-                                value);
-    g_free(value);
 
-    osinfo_loader_install_config_param(loader,
-                                       OSINFO_ENTITY(installScript),
-                                       "./config/*",
-                                       ctxt,
-                                       root,
-                                       err);
+    if (nnodes > 0) {
+        OsinfoAvatarFormat *avatar_format;
+
+        xmlNodePtr saved = ctxt->node;
+        ctxt->node = nodes[0];
+        avatar_format = osinfo_loader_avatar_format(loader, ctxt, root, err);
+        ctxt->node = saved;
+        if (error_is_set(err))
+            goto error;
+
+        osinfo_install_script_set_avatar_format(installScript, avatar_format);
+    }
+    g_free(nodes);
 
     osinfo_db_add_install_script(loader->priv->db, installScript);
 
     return;
 
  error:
+    g_free(nodes);
     g_free(value);
     g_object_unref(installScript);
 }
@@ -662,6 +737,7 @@ static OsinfoMedia *osinfo_loader_media (OsinfoLoader *loader,
     };
 
     OsinfoMedia *media = osinfo_media_new(id, arch);
+    xmlFree(arch);
 
     osinfo_loader_entity(loader, OSINFO_ENTITY(media), keys, ctxt, root, err);
     if (live) {
@@ -686,8 +762,10 @@ static OsinfoMedia *osinfo_loader_media (OsinfoLoader *loader,
     }
 
     gint nnodes = osinfo_loader_nodeset("./iso/*", ctxt, &nodes, err);
-    if (error_is_set(err))
+    if (error_is_set(err)) {
+        g_object_unref(media);
         return NULL;
+    }
 
     for (i = 0 ; i < nnodes ; i++) {
         if (!nodes[i]->children ||
@@ -731,12 +809,15 @@ static OsinfoTree *osinfo_loader_tree (OsinfoLoader *loader,
     };
 
     OsinfoTree *tree = osinfo_tree_new(id, arch);
+    xmlFree(arch);
 
     osinfo_loader_entity(loader, OSINFO_ENTITY(tree), keys, ctxt, root, err);
 
     gint nnodes = osinfo_loader_nodeset("./treeinfo/*", ctxt, &nodes, err);
-    if (error_is_set(err))
+    if (error_is_set(err)) {
+        g_object_unref(G_OBJECT(tree));
         return NULL;
+    }
 
     for (i = 0 ; i < nnodes ; i++) {
         if (!nodes[i]->children ||
@@ -810,6 +891,7 @@ static OsinfoResources *osinfo_loader_resources(OsinfoLoader *loader,
 
 EXIT:
     g_free(nodes);
+    xmlFree(arch);
 
     return resources;
 }
@@ -842,6 +924,73 @@ EXIT:
     g_clear_object(&resources);
 }
 
+static OsinfoDeviceDriver *osinfo_loader_driver(OsinfoLoader *loader,
+                                                xmlXPathContextPtr ctxt,
+                                                xmlNodePtr root,
+                                                const gchar *id,
+                                                GError **err)
+{
+    xmlNodePtr *nodes = NULL;
+    guint i;
+
+    xmlChar *arch = xmlGetProp(root, BAD_CAST OSINFO_DEVICE_DRIVER_PROP_ARCHITECTURE);
+    xmlChar *location = xmlGetProp(root, BAD_CAST OSINFO_DEVICE_DRIVER_PROP_LOCATION);
+    xmlChar *preinst = xmlGetProp(root, BAD_CAST OSINFO_DEVICE_DRIVER_PROP_PRE_INSTALLABLE);
+
+    OsinfoDeviceDriver *driver = osinfo_device_driver_new(id);
+
+    if (arch) {
+        osinfo_entity_set_param(OSINFO_ENTITY(driver),
+                                OSINFO_DEVICE_DRIVER_PROP_ARCHITECTURE,
+                                (gchar *)arch);
+        xmlFree(arch);
+    }
+
+    if (location) {
+        osinfo_entity_set_param(OSINFO_ENTITY(driver),
+                                OSINFO_DEVICE_DRIVER_PROP_LOCATION,
+                                (gchar *)location);
+        xmlFree(location);
+    }
+
+    if (preinst) {
+        osinfo_entity_set_param(OSINFO_ENTITY(driver),
+                                OSINFO_DEVICE_DRIVER_PROP_PRE_INSTALLABLE,
+                                (gchar *)preinst);
+        xmlFree(preinst);
+    }
+
+    gint nnodes = osinfo_loader_nodeset("./*", ctxt, &nodes, err);
+    if (error_is_set(err)) {
+        g_object_unref(G_OBJECT(driver));
+        return NULL;
+    }
+
+    for (i = 0 ; i < nnodes ; i++) {
+        if (nodes[i]->children &&
+            nodes[i]->children->type == XML_TEXT_NODE &&
+            (strcmp((const gchar *)nodes[i]->name,
+                    OSINFO_DEVICE_DRIVER_PROP_FILE) == 0)) {
+            osinfo_entity_add_param(OSINFO_ENTITY(driver),
+                                    (const gchar *)nodes[i]->name,
+                                    (const gchar *)nodes[i]->children->content);
+        } else if (strcmp((const gchar *)nodes[i]->name,
+                          OSINFO_DEVICE_DRIVER_PROP_DEVICE) == 0) {
+            xmlChar *device_id = xmlGetProp(nodes[i], BAD_CAST "id");
+            OsinfoDevice *device = osinfo_loader_get_device(loader,
+                                                            (gchar *)device_id);
+            xmlFree(device_id);
+
+            osinfo_device_driver_add_device(driver, device);
+        }
+    }
+
+    g_free(nodes);
+
+    return driver;
+}
+
+
 static void osinfo_loader_os(OsinfoLoader *loader,
                              xmlXPathContextPtr ctxt,
                              xmlNodePtr root,
@@ -858,7 +1007,7 @@ static void osinfo_loader_os(OsinfoLoader *loader,
         NULL
     };
     if (!id) {
-        OSINFO_ERROR(err, "Missing os id property");
+        OSINFO_ERROR(err, _("Missing os id property"));
         return;
     }
 
@@ -889,9 +1038,10 @@ static void osinfo_loader_os(OsinfoLoader *loader,
         g_free (media_id);
         ctxt->node = saved;
         if (error_is_set(err))
-            break;
+            goto cleanup;
 
         osinfo_os_add_media (os, media);
+        g_object_unref (media);
     }
 
     g_free(nodes);
@@ -908,9 +1058,10 @@ static void osinfo_loader_os(OsinfoLoader *loader,
         g_free (tree_id);
         ctxt->node = saved;
         if (error_is_set(err))
-            break;
+            goto cleanup;
 
         osinfo_os_add_tree (os, tree);
+        g_object_unref(G_OBJECT(tree));
     }
 
     g_free(nodes);
@@ -939,26 +1090,48 @@ static void osinfo_loader_os(OsinfoLoader *loader,
 
     nnodes = osinfo_loader_nodeset("./installer/script", ctxt, &nodes, err);
     if (error_is_set(err))
-        return;
+        goto cleanup;
 
     for (i = 0 ; i < nnodes ; i++) {
         gchar *scriptid = (gchar *)xmlGetProp(nodes[i], BAD_CAST "id");
         if (!scriptid) {
-            OSINFO_ERROR(err, "Missing OS install script property");
-            g_free(nodes);
+            OSINFO_ERROR(err, _("Missing OS install script property"));
             goto cleanup;
         }
         OsinfoInstallScript *script;
         script = osinfo_loader_get_install_script(loader, scriptid);
-        g_free(scriptid);
+        xmlFree(scriptid);
 
         osinfo_os_add_install_script(os, script);
     }
 
     g_free(nodes);
 
+    nnodes = osinfo_loader_nodeset("./driver", ctxt, &nodes, err);
+    if (error_is_set(err))
+        goto cleanup;
+
+    for (i = 0 ; i < nnodes ; i++) {
+        xmlNodePtr saved = ctxt->node;
+        ctxt->node = nodes[i];
+        gchar *driver_id = g_strdup_printf("%s:%u", id, i);
+        OsinfoDeviceDriver *driver= osinfo_loader_driver(loader,
+                                                         ctxt,
+                                                         nodes[i],
+                                                         driver_id,
+                                                         err);
+        g_free (driver_id);
+        ctxt->node = saved;
+        if (error_is_set(err))
+            break;
+
+        osinfo_os_add_device_driver(os, driver);
+        g_object_unref(driver);
+    }
+
 cleanup:
-    g_free(id);
+    g_free(nodes);
+    xmlFree(id);
 }
 
 static void osinfo_loader_root(OsinfoLoader *loader,
@@ -976,7 +1149,8 @@ static void osinfo_loader_root(OsinfoLoader *loader,
      *   Advance tag
      *   If closing libosinfo tag, break
      *   If non element tag, continue
-     *   If element tag, and element is not os, platform or device, error
+     *   If element tag, and element is not os, platform, device,
+     *   deployment or install-script, error
      *   Else, switch on tag type and handle reading in data
      * After loop, return success if no error
      * If there was an error, clean up lib data acquired so far
@@ -994,7 +1168,7 @@ static void osinfo_loader_root(OsinfoLoader *loader,
     int ninstallScript;
 
     if (!xmlStrEqual(root->name, BAD_CAST "libosinfo")) {
-        OSINFO_ERROR(err, "Incorrect root element");
+        OSINFO_ERROR(err, _("Incorrect root element"));
         return;
     }
 
@@ -1102,7 +1276,7 @@ static void osinfo_loader_process_xml(OsinfoLoader *loader,
     /* Set up a parser context so we can catch the details of XML errors. */
     pctxt = xmlNewParserCtxt();
     if (!pctxt || !pctxt->sax) {
-        OSINFO_ERROR(err, "Unable to construct parser context");
+        OSINFO_ERROR(err, _("Unable to construct parser context"));
         goto cleanup;
     }
 
@@ -1124,7 +1298,7 @@ static void osinfo_loader_process_xml(OsinfoLoader *loader,
     root = xmlDocGetRootElement(xml);
 
     if (!root) {
-        OSINFO_ERROR(err, "Missing root element");
+        OSINFO_ERROR(err, _("Missing root XML element"));
         goto cleanup;
     }
 
