@@ -25,6 +25,7 @@
 #include <config.h>
 
 #include <osinfo/osinfo.h>
+#include <glib/gi18n-lib.h>
 
 G_DEFINE_TYPE (OsinfoMediaList, osinfo_medialist, OSINFO_TYPE_LIST);
 
@@ -91,6 +92,7 @@ OsinfoMediaList *osinfo_medialist_new(void)
  * from @source
  *
  * Returns: (transfer full): a copy of the media list
+ * Deprecated: 0.2.2: Use osinfo_list_new_copy() instead.
  */
 OsinfoMediaList *osinfo_medialist_new_copy(OsinfoMediaList *source)
 {
@@ -109,6 +111,7 @@ OsinfoMediaList *osinfo_medialist_new_copy(OsinfoMediaList *source)
  * from @source that match @filter
  *
  * Returns: (transfer full): a filtered copy of the media list
+ * Deprecated: 0.2.2: Use osinfo_list_new_filtered() instead.
  */
 OsinfoMediaList *osinfo_medialist_new_filtered(OsinfoMediaList *source,
                                                OsinfoFilter *filter)
@@ -129,6 +132,7 @@ OsinfoMediaList *osinfo_medialist_new_filtered(OsinfoMediaList *source,
  * medias that are present in both @sourceOne and @sourceTwo.
  *
  * Returns: (transfer full): an intersection of the two media lists
+ * Deprecated: 0.2.2: Use osinfo_list_new_intersection() instead.
  */
 OsinfoMediaList *osinfo_medialist_new_intersection(OsinfoMediaList *sourceOne,
                                                    OsinfoMediaList *sourceTwo)
@@ -149,6 +153,7 @@ OsinfoMediaList *osinfo_medialist_new_intersection(OsinfoMediaList *sourceOne,
  * medias that are present in either @sourceOne and @sourceTwo.
  *
  * Returns: (transfer full): a union of the two media lists
+ * Deprecated: 0.2.2: Use osinfo_list_new_union() instead.
  */
 OsinfoMediaList *osinfo_medialist_new_union(OsinfoMediaList *sourceOne,
                                             OsinfoMediaList *sourceTwo)
