@@ -25,6 +25,7 @@
 #include <config.h>
 
 #include <osinfo/osinfo.h>
+#include <glib/gi18n-lib.h>
 
 G_DEFINE_TYPE (OsinfoOs, osinfo_os, OSINFO_TYPE_PRODUCT);
 
@@ -53,6 +54,8 @@ struct _OsinfoOsPrivate
     OsinfoResourcesList *recommended;
 
     OsinfoInstallScriptList *scripts;
+
+    OsinfoDeviceDriverList *device_drivers;
 };
 
 struct _OsinfoOsDeviceLink {
@@ -113,6 +116,8 @@ osinfo_os_finalize (GObject *object)
 
     g_object_unref(os->priv->scripts);
 
+    g_object_unref(os->priv->device_drivers);
+
     /* Chain up to the parent class */
     G_OBJECT_CLASS (osinfo_os_parent_class)->finalize (object);
 }
@@ -137,7 +142,7 @@ osinfo_os_class_init (OsinfoOsClass *klass)
      */
     pspec = g_param_spec_string ("family",
                                  "Family",
-                                 "Generic Family",
+                                 _("Generic Family"),
                                  NULL /* default value */,
                                  G_PARAM_READABLE |
                                  G_PARAM_STATIC_NAME |
@@ -155,7 +160,7 @@ osinfo_os_class_init (OsinfoOsClass *klass)
      */
     pspec = g_param_spec_string ("distro",
                                  "Distro",
-                                 "Generic Distro",
+                                 _("Generic Distro"),
                                  NULL /* default value */,
                                  G_PARAM_READABLE |
                                  G_PARAM_STATIC_NAME |
@@ -178,6 +183,7 @@ osinfo_os_init (OsinfoOs *os)
     os->priv->minimum = osinfo_resourceslist_new ();
     os->priv->recommended = osinfo_resourceslist_new ();
     os->priv->scripts = osinfo_install_scriptlist_new ();
+    os->priv->device_drivers = osinfo_device_driverlist_new ();
 }
 
 /**
@@ -250,7 +256,8 @@ OsinfoDeviceList *osinfo_os_get_all_devices(OsinfoOs *os, OsinfoFilter *filter)
                 (OSINFO_PRODUCT(os), OSINFO_PRODUCT_RELATIONSHIP_DERIVES_FROM);
     cloned = osinfo_product_get_related(OSINFO_PRODUCT(os),
                                         OSINFO_PRODUCT_RELATIONSHIP_CLONES);
-    related_list = osinfo_productlist_new_union(derived, cloned);
+    related_list = OSINFO_PRODUCTLIST(osinfo_list_new_union(OSINFO_LIST(derived),
+                                                            OSINFO_LIST(cloned)));
     g_object_unref(derived);
     g_object_unref(cloned);
 
@@ -262,7 +269,8 @@ OsinfoDeviceList *osinfo_os_get_all_devices(OsinfoOs *os, OsinfoFilter *filter)
         related_devices = osinfo_os_get_all_devices(OSINFO_OS(related), filter);
         if (osinfo_list_get_length(OSINFO_LIST(related_devices)) > 0) {
             OsinfoDeviceList *tmp_list = devices;
-            devices = osinfo_devicelist_new_union(devices, related_devices);
+            devices = OSINFO_DEVICELIST(osinfo_list_new_union(OSINFO_LIST(devices),
+                                                              OSINFO_LIST(related_devices)));
             g_object_unref(tmp_list);
         }
     }
@@ -553,14 +561,18 @@ OsinfoInstallScript *osinfo_os_find_install_script(OsinfoOs *os, const gchar *pr
 
 /**
  * osinfo_os_get_install_script_list:
+ * @os: an operating system
  *
  * Returns: (transfer full): a list of the install scripts for the specified os
  */
 OsinfoInstallScriptList *osinfo_os_get_install_script_list(OsinfoOs *os)
 {
-    g_return_val_if_fail(OSINFO_IS_OS(os), NULL);
+    OsinfoList *new_list;
 
-    return osinfo_install_scriptlist_new_copy(os->priv->scripts);
+    g_return_val_if_fail(OSINFO_IS_OS(os), NULL);
+    new_list = osinfo_list_new_copy(OSINFO_LIST(os->priv->scripts));
+
+    return OSINFO_INSTALL_SCRIPTLIST(new_list);
 }
 
 
@@ -571,6 +583,30 @@ void osinfo_os_add_install_script(OsinfoOs *os, OsinfoInstallScript *script)
     osinfo_list_add(OSINFO_LIST(os->priv->scripts), OSINFO_ENTITY(script));
 }
 
+/**
+ * osinfo_os_get_device_drivers:
+ * @os: an operating system
+ *
+ * Gets list of all available device drivers for OS @os.
+ *
+ * Returns: (transfer none): A list of device drivers
+ */
+OsinfoDeviceDriverList *osinfo_os_get_device_drivers(OsinfoOs *os)
+{
+    g_return_val_if_fail(OSINFO_IS_OS(os), NULL);
+
+    return os->priv->device_drivers;
+}
+
+void osinfo_os_add_device_driver(OsinfoOs *os, OsinfoDeviceDriver *driver)
+{
+    g_return_if_fail(OSINFO_IS_OS(os));
+    g_return_if_fail(OSINFO_IS_DEVICE_DRIVER(driver));
+
+    osinfo_list_add(OSINFO_LIST(os->priv->device_drivers),
+                    OSINFO_ENTITY(driver));
+}
+
 /*
  * Local variables:
  *  indent-tabs-mode: nil
