@@ -25,6 +25,8 @@
 
 #include <osinfo/osinfo.h>
 #include <string.h>
+#include <locale.h>
+#include <glib/gi18n.h>
 
 static const gchar *profile;
 static const gchar *output_dir;
@@ -43,7 +45,7 @@ static gboolean handle_config(const gchar *option_name G_GNUC_UNUSED,
 
     if (!(val = strchr(value, '='))) {
         g_set_error(error, 0, 0,
-                    "Expected configuration key=value");
+                    _("Expected configuration key=value"));
         return FALSE;
     }
     len = val - value;
@@ -61,14 +63,14 @@ static gboolean handle_config(const gchar *option_name G_GNUC_UNUSED,
 static GOptionEntry entries[] =
 {
     { "profile", 'p', 0, G_OPTION_ARG_STRING, (void*)&profile,
-      "Install script profile", NULL, },
+      N_("Install script profile"), NULL, },
     { "output-dir", 'd', 0, G_OPTION_ARG_STRING, (void*)&output_dir,
-      "Install script output directory", NULL, },
+      N_("Install script output directory"), NULL, },
     { "prefix", 'P', 0, G_OPTION_ARG_STRING, (void*)&prefix,
-      "The output filename prefix", NULL, },
+      N_("The output filename prefix"), NULL, },
     { "config", 'c', 0, G_OPTION_ARG_CALLBACK,
       handle_config,
-      "Set configuration parameter", "key=value" },
+      N_("Set configuration parameter"), "key=value" },
     { NULL }
 };
 
@@ -92,8 +94,8 @@ static OsinfoOs *find_os(OsinfoDb *db,
                                  OSINFO_PRODUCT_PROP_SHORT_ID,
                                  idoruri);
 
-    filteredList = osinfo_oslist_new_filtered(oslist,
-                                              filter);
+    filteredList = OSINFO_OSLIST(osinfo_list_new_filtered(OSINFO_LIST(oslist),
+                                                          filter));
 
     if (osinfo_list_get_length(OSINFO_LIST(filteredList)) > 0)
         os = OSINFO_OS(osinfo_list_get_nth(OSINFO_LIST(filteredList), 0));
@@ -120,8 +122,8 @@ static gboolean generate_script(OsinfoOs *os)
                                  OSINFO_INSTALL_SCRIPT_PROP_PROFILE,
                                  profile ? profile :
                                  OSINFO_INSTALL_SCRIPT_PROFILE_JEOS);
-    profile_scripts = osinfo_install_scriptlist_new_filtered(scripts,
-                                                            filter);
+    profile_scripts = OSINFO_INSTALL_SCRIPTLIST(osinfo_list_new_filtered(OSINFO_LIST(scripts),
+                                                                         filter));
     l = osinfo_list_get_elements(OSINFO_LIST(profile_scripts));
     for (tmp = l; tmp != NULL; tmp = tmp->next) {
         OsinfoInstallScript *script = tmp->data;
@@ -138,8 +140,8 @@ static gboolean generate_script(OsinfoOs *os)
                                               NULL,
                                               &error);
         if (error != NULL) {
-            g_printerr("Unable to generate install script: %s\n",
-                    error->message ? error->message : "unknown");
+            g_printerr(_("Unable to generate install script: %s\n"),
+                       error->message ? error->message : "unknown");
             goto cleanup;
         }
     }
@@ -163,15 +165,19 @@ gint main(gint argc, gchar **argv)
     OsinfoOs *os = NULL;
     gint ret = 0;
 
+    setlocale(LC_ALL, "");
+    textdomain (GETTEXT_PACKAGE);
+    bindtextdomain(GETTEXT_PACKAGE, LOCALEDIR);
+    bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
+
     g_type_init();
 
     config = osinfo_install_config_new("http://libosinfo.fedorahosted.org/config");
 
-    context = g_option_context_new("- Generate an OS install script");
-    /* FIXME: We don't have a gettext package to pass to this function. */
-    g_option_context_add_main_entries(context, entries, NULL);
+    context = g_option_context_new(_("- Generate an OS install script"));
+    g_option_context_add_main_entries(context, entries, GETTEXT_PACKAGE);
     if (!g_option_context_parse(context, &argc, &argv, &error)) {
-        g_printerr("Error while parsing options: %s\n", error->message);
+        g_printerr(_("Error while parsing options: %s\n"), error->message);
         g_printerr("%s\n", g_option_context_get_help(context, FALSE, NULL));
 
         ret = -1;
@@ -188,7 +194,7 @@ gint main(gint argc, gchar **argv)
     loader = osinfo_loader_new();
     osinfo_loader_process_default_path(loader, &error);
     if (error != NULL) {
-        g_printerr("Error loading OS data: %s\n", error->message);
+        g_printerr(_("Error loading OS data: %s\n"), error->message);
 
         ret = -3;
         goto EXIT;
@@ -197,7 +203,7 @@ gint main(gint argc, gchar **argv)
     db = osinfo_loader_get_db(loader);
     os = find_os(db, argv[1]);
     if (!os) {
-        g_printerr("Error finding OS: %s\n", argv[1]);
+        g_printerr(_("Error finding OS: %s\n"), argv[1]);
         ret = -4;
         goto EXIT;
     }
